
Object subclass: #OrderPosition
    instanceVariableNames: 'product quantity date '
    classVariableNames: ''
    poolDictionaries: ''!

OrderPosition comment: 'Diese Klasse entspricht der Klasse Bestellposten aus der OBA-Analyse.

Instanzvariablen:
	product <Product>
		Bestelltes ''Produkt''.
	quantity <Number>
		Bestellte ''Menge''.
	date <Date>
		''Datum'' der Bearbeitung.
'!

!OrderPosition class publicMethods !

new
	"Instanzvariablen werden initialisiert."
	^super new initialize
! !

OrderPosition class categoriesFor: #new are:((OrderedCollection new)
	add: 'Create';
	yourself)!

!OrderPosition publicMethods !

date
	"Zugriff 'Datum'."
	"Bestimmt das Bestelldatum des bestellten Produkts."
	^date
!

date: aDate
	"Legt das Bestelldatum des bestellten Produkts fest."
	date := aDate
!

initialize
	"Anfangswerte werden gesetzt."
	product := nil.
	quantity := 0.
	date := Date today
!

logOrderPosition
	"Entspricht der Dienstleistung 'Verbuchung-Bestellung'."
	self product logOrderPosition: self!

printString
	"Listet die Bestellung auf."
	^self date printString , ': ' , self quantity printString ,
		' units of ' , self product printString
!

product
	"Zugriff 'Produkt'."
	"Ermittelt das bestellte Produkt."
	^product
!

product: aProduct
	"Legt das bestellte Produkt fest."
	product := aProduct

!

quantity
	"Ermittelt die bestellte Menge des Produkts."
	^quantity
!

quantity: aNumber
	"Legt die bestellte Menge des Produkts fest."
	quantity := aNumber

!

release
	"Objektdaten werden geloescht."
	product := nil.
	quantity := nil.
	date := nil
! !

OrderPosition categoriesFor: #date: are:((OrderedCollection new)
	add: 'Accessing';
	yourself)!
OrderPosition categoriesFor: #logOrderPosition are:((OrderedCollection new)
	add: 'Services';
	yourself)!
OrderPosition categoriesFor: #date are:((OrderedCollection new)
	add: 'Accessing';
	yourself)!
OrderPosition categoriesFor: #printString are:((OrderedCollection new)
	add: 'Printing';
	yourself)!
OrderPosition categoriesFor: #initialize are:((OrderedCollection new)
	add: 'Initialize';
	yourself)!
OrderPosition categoriesFor: #quantity: are:((OrderedCollection new)
	add: 'Accessing';
	yourself)!
OrderPosition categoriesFor: #quantity are:((OrderedCollection new)
	add: 'Accessing';
	yourself)!
OrderPosition categoriesFor: #release are:((OrderedCollection new)
	add: 'Initialize';
	yourself)!
OrderPosition categoriesFor: #product are:((OrderedCollection new)
	add: 'Accessing';
	yourself)!
OrderPosition categoriesFor: #product: are:((OrderedCollection new)
	add: 'Accessing';
	yourself)!