
Object subclass: #StorageArea
    instanceVariableNames: 'size places '
    classVariableNames: ''
    poolDictionaries: ''!

StorageArea comment: 'Diese Klasse entspricht der Klasse Lagerbereich aus der OBA-Analyse.

Instanzvariablen:
	size <Point>
		''Groesse'' des Lagerbereiches.
	places <Dictionary>
		''Belegt''e Plaetze bzw Faecher des Lagerbereiches.'!

!StorageArea class publicMethods !

new
	"Objekte der Klasse sollten nicht erzeugt werden."
	^self shouldNotImplement!

new: aPoint
	"Erzeugt einen neuen Lagerbereich mit der angegebenen Ausdehnung"
	^super new initialize: aPoint! !

StorageArea class categoriesFor: #new are:((OrderedCollection new)
	add: 'Create';
	yourself)!
StorageArea class categoriesFor: #new: are:((OrderedCollection new)
	add: 'Create';
	yourself)!

!StorageArea publicMethods !

at: aPoint
	"Inhalt des Platzes aPoint."
	aPoint <= self size ifFalse: [^self error: 'No such place.'].
	^places at: aPoint ifAbsent: []!

choosePlace
	"Entspricht der Dienstleistung 'Auswahl'."
	1 to: self size x do:
		 [:u | 1 to: self size y do: 
			[:v | (self isUsedAt: u @ v) ifFalse: [^u @ v]]].
	^nil
	!

initialize: aPoint
	"Instanzvariablen werden initialisiert."
	size := aPoint.
	places := Dictionary new!

isUsedAt: aPoint
	"Zugriff 'Belegt'."
	"Liefert true, falls Platz aPoint besetzt, sonst false."
	^(places at: aPoint ifAbsent:[]) notNil!

placeOf: anObject
	"Sucht das Objekt anObject und gibt den Platz,
	 auf dem es gefunden wurde, zurueck."
	^places keyAtValue: anObject ifAbsent: []!

release
	"Objektdaten werden geloescht."
	size := nil.
	places := nil!

size
	"Zugriff 'Groesse'."
	"Gibt die Ausdehnung des Lagerbereiches an."
	^size!

totalSpace
	"Anzahl der verfuegbaren Plaetze"
	^self size x * self size y!

usedPlacesDo: aBinaryBlock
	"Wertet aBinaryBlock fuer jeden belegten Platz aus.
	aBinaryBlock muss genau zwei Argumente haben. Das erste
	Argument ist die Koordinate des Platzes und das zweite
	Argument ist der Platz selbst."
	places keysAndValuesDo:
		[ :point :place | aBinaryBlock value: point value: place]
!

usedSpace
	"Anzahl der belegten Plaetze"
	^places keys size! !

StorageArea categoriesFor: #isUsedAt: are:((OrderedCollection new)
	add: 'Testing';
	yourself)!
StorageArea categoriesFor: #release are:((OrderedCollection new)
	add: 'Initialize';
	yourself)!
StorageArea categoriesFor: #initialize: are:((OrderedCollection new)
	add: 'Initialize';
	yourself)!
StorageArea categoriesFor: #at: are:((OrderedCollection new)
	add: 'Accessing';
	yourself)!
StorageArea categoriesFor: #placeOf: are:((OrderedCollection new)
	add: 'Accessing';
	yourself)!
StorageArea categoriesFor: #usedPlacesDo: are:((OrderedCollection new)
	add: 'Enumerating';
	yourself)!
StorageArea categoriesFor: #usedSpace are:((OrderedCollection new)
	add: 'Accessing';
	yourself)!
StorageArea categoriesFor: #choosePlace are:((OrderedCollection new)
	add: 'Services';
	yourself)!
StorageArea categoriesFor: #size are:((OrderedCollection new)
	add: 'Accessing';
	yourself)!
StorageArea categoriesFor: #totalSpace are:((OrderedCollection new)
	add: 'Accessing';
	yourself)!